/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/
/*******************************************************************************
* File Name    : main.c
* Device(s)    : RX64M
* Tool-Chain   : Renesas RX
* Description  : This is a simple demo of the RX64M RIIC for the RSKRX64M
*                starter kit (FIT module "r_riic_rx").
* Operation    : 1. Compile and download the sample code. Click 'Reset Go'
*                   to start the software.
* Limitations  :
*******************************************************************************/
/*******************************************************************************
* History : DD.MM.YYYY Version  Description
*           31.08.2017 1.00     First Release.
*******************************************************************************/

/*****************************************************************************
Includes   <System Includes> , "Project Includes"
******************************************************************************/
#include <stdio.h>
#include <string.h>
#include "platform.h"
#include "r_riic_rx_if.h"
#include "r_riic_rx_config.h"
#include "r_riic_rx_pin_config.h"
/*****************************************************************************
 * Global definition
 ******************************************************************************/

static uint32_t send_count = 0;     /* transferCompletion  flag */
static void master_call_back(void); /* Master callback function */
static riic_info_t iic_info_m;      /* handler of RIIC Transfer */

/*******************************************************************************
* Function Name: main
* Description  : demo main of riic communication (master send)
* Arguments    : none
* Return Value : void
*******************************************************************************/
void main(void)
{
    uint32_t version_id = 0;
    volatile riic_return_t ret;
    uint8_t addr_eeprom[1] = {0x50};
    uint8_t access_addr1[1] = {0x00};
    uint8_t mst_send_data[8] = {'R','e','n','e','s','a','s','\0'};
    iic_info_m.dev_sts = RIIC_NO_INIT;      /*init the riic communication structure*/
    iic_info_m.ch_no = 2;
    iic_info_m.callbackfunc = &master_call_back;
    iic_info_m.cnt2nd = 7;
    iic_info_m.cnt1st = 1;
    iic_info_m.p_data2nd = mst_send_data;
    iic_info_m.p_data1st = access_addr1;
    iic_info_m.p_slv_adr = addr_eeprom;
    printf("iic_info_m.p_data2nd = %s\n",mst_send_data);
    ret = R_RIIC_Open(&iic_info_m);         /* Open RIIC */

    while(1)
    {
    	ret = R_RIIC_MasterSend(&iic_info_m);   /* RIIC Master Send Start */
    }
//    if (RIIC_SUCCESS != ret)
//    {
//        printf("Master Send failed ,return Value is %d\n",ret);
//        R_RIIC_Close(&iic_info_m);
//        return;
//    }
//    else
//    {
//        while (1)
//        {
//            if (RIIC_FINISH != iic_info_m.dev_sts)       /* To determine whether the transmission is over */
//            {
//                if(RIIC_NACK != iic_info_m.dev_sts)      /* To determine whether the status is NACK */
//                {
//                    if(RIIC_TMO != iic_info_m.dev_sts)   /* To determine whether the status is TimeOut */
//                    {
//                        continue;
//                    }
//                    else
//                    {
//                        printf("RIIC Transfer is Time out\n");     /* RIIC Transfer is Time out */
//                        break;
//                    }
//                }
//                else
//                {
//                    if (send_count >= 200)
//                    {
//                        printf("the number of send times is %d\n",send_count);
//                        break;
//                    }
//                    else
//                    {
//                        R_BSP_SoftwareDelay(100, BSP_DELAY_MICROSECS);
//                        send_count++;                          /* send count plus 1,and send data once more   */
//
//                        iic_info_m.dev_sts = RIIC_NO_INIT;
//                        iic_info_m.cnt2nd = 7;
//                        iic_info_m.cnt1st = 1;
//                        iic_info_m.p_data2nd = mst_send_data;
//                        iic_info_m.p_data1st = access_addr1;
//
//                        ret = R_RIIC_MasterSend(&iic_info_m);
//
//                        if (RIIC_SUCCESS != ret)
//                        {
//                            printf("Master Send failed ,return Value is %d\n",ret);
//                            break;
//                        }
//                        else
//                        {
//                            printf("the number of send times is %d\n",send_count);
//                            continue;
//                        }
//                    }
//                }
//            }
//            else
//            {
//                printf("iic_info_m.dev_sts = %d\n",iic_info_m.dev_sts);
//                printf("Master send Data has finished\n");
//                break;
//            }
//        }
//    }
//    do
//    {
//        ret = R_RIIC_Close(&iic_info_m);
//    }while(RIIC_SUCCESS != ret);
//    printf("RIIC transfer is over,close the RIIC Channel\n");
//    return;
}
/*******************************************************************************
End of function main
*******************************************************************************/

/*******************************************************************************
 * Function Name : master_call_back
 * Description   : callback function of RIIC API
 * Arguments     : void
 * Return Value  : void
 *******************************************************************************/
static void master_call_back(void)
{
    volatile riic_return_t ret;
    riic_mcu_status_t iic_status;

    /* Get I2C Status */
    ret = R_RIIC_GetStatus(&iic_info_m, &iic_status);
    if (RIIC_SUCCESS != ret)
    {
        printf("Get I2C Status failed\n");
    }
    else
    {
        printf("iic_status.LONG = %x\n",iic_status.LONG);
    }

    return;
}
/*******************************************************************************
End of function master_call_back
*******************************************************************************/
